@@ -258,14 +258,19 @@ class Worker:
         blobs_iterator = self._read_blob_by_segments(in_blob)
         for segment in blobs_iterator:
             batch.append(segment)
-            if len(batch) == self.segment_limit:
+            if self.segment_limit is not None and len(batch) == self.segment_limit:
                 result, failures = func(batch, params)
                 batch = []
                 break
 
-        if len(batch) > 0: # If segments in blob are less than segment_limit
+        if len(batch) > 0: 
+            # If segments in blob are less than segment_limit or there is no segment limit at all
             result, failures = func(batch, params)
 
+        if self.segment_limit is None:
+            # If there is no segment limit, then blob is processed in one batch
+            return result, failures, []
+            
         next_chunk = []
         for segment in blobs_iterator:
             next_chunk.append(segment)
